## Description
<!-- Describe your changes in detail -->

## Type of Change
<!-- What types of changes does your code introduce? Put an `x` in all the boxes that apply: -->
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Performance improvement
- [ ] Security enhancement
- [ ] Code cleanup or refactor
- [ ] Infrastructure update
- [ ] Other (please describe):

## Context for AI Reviewer
<!-- Provide any additional context that would help the AI reviewer understand your changes better -->
<!-- For example: architectural decisions, business logic changes, performance considerations -->

### Key Areas to Review
<!-- List specific areas you'd like the AI to focus on during the review -->
<!-- Example:
- Error handling and edge cases
- Security considerations
- Performance optimizations
- Integration points
- Test coverage
-->

### Related Issues
<!-- Link to any related issues or tickets -->
<!-- Example:
- Fixes #123
- Implements #456
- Addresses #789
-->

### Testing Done
<!-- Describe the tests you've added or run to verify your changes -->
<!-- Example:
- Added unit tests for [specific component]
- Integration tests for [specific scenario]
- Load tested with [specific parameters]
- Security testing completed
- Performance benchmarks run
-->

### Additional Notes
<!-- Any additional information that would help with the review -->
<!-- Example:
- Known limitations or trade-offs
- Future improvements planned
- Migration steps required
- Dependencies affected
-->